# Contiene tutte le regole di modifica del documento
from pathlib import Path
import logging
import re

from gtagger.convert import TikaConverter
from gtagger.model import Document, parse_iso_date
from gtagger.date_helper import DateHelper

log = logging.getLogger(__name__)


class DocumentPostProcessor:
    def __init__(self):
        self.tika = TikaConverter()

    def apply_language_rules(self, doc: Document, md_source_path: str) -> None:
        log.debug("Applico path tipo documento in relazione a lingua")
        language = self.tika.get_language(Path(md_source_path))
        old_type = doc.tipo_documento
        if doc.tipo_documento == "cs" and language == "en":
            doc.tipo_documento = "pr"
        elif doc.tipo_documento == "dis" and language == "en":
            doc.tipo_documento = "sp"

        # Regola salvataggio per non riprocessare tutto con l'ia, TEMPORANEA
        elif doc.tipo_documento == "pr" and language == "it":
            doc.tipo_documento = "cs"
        elif doc.tipo_documento == "sp" and language == "it":
            doc.tipo_documento = "dis"
        
        log.debug(f"Lingua rilevata: {language}, documento tipo {old_type} -> {doc.tipo_documento}")


    def apply_date_rules(self, doc: Document, file_source_path: str, filename_info: dict) -> None:
        extracted_date = filename_info.get("date")
        if  extracted_date and DateHelper.is_acceptable_data(extracted_date):
            doc.data_evento = extracted_date
        elif parse_iso_date(doc.data_evento) is None:
            doc.data_evento = DateHelper.get_last_change(file_source_path)
        log.debug(f"data registrata: {doc.data_evento}")


    def apply_filename_type_rules(self, doc: Document, filename: str) -> None:
        filename = filename.lower()
        filename = re.sub(r"\W", "_", filename)
        filename = "".join(filename.split("_"))
        sentinels = [("invito", "std"), ("savethedate", "std")]
        for flag in sentinels:
            if flag[0] in filename:
                doc.tipo_documento == flag[1]
                break
             